@@ -2,8 +2,8 @@
 {
 	if (missing(model))
 		stop("model is missing");
-	if (!inherits(model, "variogram.model"))
-		stop("model should be of mode variogram.model (use function vgm)")
+	if (!inherits(model, "variogramModel"))
+		stop("model should be of mode variogramModel (use function vgm)")
 	anis = c(model$ang1, model$ang2, model$ang3, model$anis1, model$anis2)
 	.C("Cgstat_load_variogram", 
 		as.integer(ids),
